This patch fixes a few of the complaints about GLINE on Hybrid 6 from
opers on EFnet.

1.  Even though we can't support IPv6, still allow opers on this server
    to vote for GLINE's for IPv6 users (As long as the : only exists in
    the hostname.)
2.  Cosmetic corrections to the "already voted" message.
3.  When a gline is triggered, expire any GLINE requests matching it from
    the pending list.

-Hwy
--- /home/wcampbel/fr/ircd-hybrid-6.3.1.dist/src/m_gline.c	Sat Dec 15 11:24:09 2001
+++ m_gline.c	Sat Jan 25 14:52:27 2003
@@ -403,7 +403,7 @@
   }
   
   /* dont allow glines with : in, theyll break the conf */
-  if(strchr(luser, ':') || strchr(lhost, ':') || strchr(lreason, ':'))
+  if(strchr(luser, ':') || strchr(lreason, ':'))
   {
     if(local_client)
       sendto_one(sptr, ":%s NOTICE %s :Invalid character ':' in gline",
@@ -533,7 +533,10 @@
   if (safe_write(sptr,filenamebuf,out,buffer))
     return;
 
-  ircsprintf(buffer, "K:%s:%s:%s\n", host,user,reason);
+  if (strchr(host, ':'))
+    ircsprintf(buffer, "# IPv6 Host, invalid (%s@%s) [%s]", user,host,reason);
+  else
+    ircsprintf(buffer, "K:%s:%s:%s\n", host,user,reason);
   if (safe_write(sptr,filenamebuf,out,buffer))
     return;
 
@@ -852,6 +855,20 @@
           MyFree(tmp_pending_ptr->reason2);
           MyFree(tmp_pending_ptr);
         }
+      else if( find_is_glined(gline_pending_ptr->host, gline_pending_ptr->user))
+        {
+          /* Expire any pending GLINE's if they were triggered and set. */
+          if(last_gline_pending_ptr)
+            last_gline_pending_ptr->next = gline_pending_ptr->next;
+          else
+            pending_glines = gline_pending_ptr->next;
+
+          tmp_pending_ptr = gline_pending_ptr;
+          gline_pending_ptr = gline_pending_ptr->next;
+          MyFree(tmp_pending_ptr->reason1);
+          MyFree(tmp_pending_ptr->reason2);
+          MyFree(tmp_pending_ptr);
+        }
       else
         {
           last_gline_pending_ptr = gline_pending_ptr;
@@ -944,7 +961,8 @@
               (irccmp(gline_pending_ptr->oper_server1,oper_server) == 0) )
             {
               /* This oper or server has already "voted" */
-              sendto_realops("oper or server has already voted");
+              sendto_realops("oper or server has already voted: [%s!%s@%s] on %s",
+                             oper_nick, oper_user, oper_host, oper_server);
               return NO;
             }
 
@@ -957,7 +975,8 @@
                   (irccmp(gline_pending_ptr->oper_server2,oper_server)==0))
                 {
                   /* This oper or server has already "voted" */
-                  sendto_realops("oper or server has already voted");
+                  sendto_realops("oper or server has already voted: [%s!%s@%s] on %s",
+                                 oper_nick, oper_user, oper_host, oper_server);
                   return NO;
                 }
 
